===========
Cheat sheet
===========

See the :download:`conda cheatsheet <conda-cheatsheet.pdf>` PDF
(1 MB) for a single-page summary of the most important
information about using conda (link points always to the latest version).

Versions
========

..
    Maintainers! When updating the following list, please make sure to
    update the filesystem symlink "conda-cheatsheet.pdf" to the latest
    version as well, to keep the URL of the conda cheetsheet the same.
    Thank you!

- :download:`conda 4.12.x <cheatsheets/conda-4.12.pdf>` (latest)

- :download:`conda 4.6.x <cheatsheets/conda-4.6.pdf>`
